    #######################################################################
    # Module: EGRRext
    # Name  : ShiftRow (local member)
    #
    # Input:
    #     rw - the row of the explicit matrix
    #     r - number of "shifts" to perform
    #     x - variable
    #     n - the size of the explicit matrix block
    #     cd - the length pf the row
    #     lt - one of 'lead' or 'trail' ('lead' is by default)
    #
    # Output:
    #     r times "shifted" row, the shift operation depends on the case and 
    #       correspond to the application of the operators D, E-1, Q-1 to
    #       the row (if 'lead' is givev) and E^{-1}-1 (if 'trail' is given - 
    #       valid only for the difference case)
    #
    #######################################################################

    ShiftRow := proc(rw0, r, x, n, cd, lt:='lead')
        local
            rw, dummy, V;

        rw := convert(rw0, list);

        dummy := Vector[row](cd, 0);
        V := Vector[row](rw);
        if lt='lead' then
             dummy[1 .. cd-n*r] := LinearAlgebra:-Map(z->dualnormal(eval(z, x=x+r)), Vector[row](V[n*r+1 .. cd]));
        else
             dummy[n*r+1 .. cd] := LinearAlgebra:-Map(z->dualnormal(eval(z, x=x-r)), Vector[row](V[1 .. cd-n*r]));
        end if;           
        eval(dummy);
    end proc;

    #######################################################################

